@@ -13,8 +13,8 @@ double ce_(NumericVector actual, NumericVector predicted) {
 
   double Rows = predicted.size();
   double ErrorCount = 0;
-
-  for(int i = 0; i < Rows; ++i) {
+#pragma omp parallel for
+  for(int i = 0; i < (int) Rows; ++i) {
     if(actual(i) != predicted(i)) {
       ErrorCount = ErrorCount + 1;
     }
@@ -51,7 +51,7 @@ double msle_(NumericVector actual, NumericVector predicted) {
 // [[Rcpp::export]]
 double rmsle_(NumericVector actual, NumericVector predicted) {
 
-  double rmsle = sqrt(mse_(actual, predicted));
+  double rmsle = sqrt(msle_(actual, predicted));
   return rmsle;
 
 }
